@@ -10,7 +10,14 @@ from pytablewriter.style import Cell, Style
 from typepy import Bool, Integer, StrictLevel
 from typepy.error import TypeConversionError
 
-from ._const import BGColor, Default, EnvVar, FGColor, Header, HelpMsg, Ini
+from ._const import BGColor, ColorPoicy, Default, EnvVar, FGColor, Header, HelpMsg, Ini, ZerosRender
+
+
+def zero_to_nullstr(value) -> str:
+    if value == 0:
+        return ""
+
+    return value
 
 
 def pytest_addoption(parser):
@@ -32,10 +39,23 @@ def pytest_addoption(parser):
     )
     group.addoption(
         "--md-report-color",
-        choices=["auto", "text", "never"],
+        choices=ColorPoicy.LIST,
         default=None,
         help=HelpMsg.MD_REPORT_COLOR + HelpMsg.EXTRA_MSG_TEMPLATE.format(EnvVar.MD_REPORT_COLOR),
     )
+    group.addoption(
+        "--md-report-margin",
+        metavar="MARGIN",
+        type=int,
+        default=None,
+        help=HelpMsg.MD_REPORT_MARGIN + HelpMsg.EXTRA_MSG_TEMPLATE.format(EnvVar.MD_REPORT_MARGIN),
+    )
+    group.addoption(
+        "--md-report-zeros",
+        choices=ZerosRender.LIST,
+        default=None,
+        help=HelpMsg.MD_REPORT_ZEROS + HelpMsg.EXTRA_MSG_TEMPLATE.format(EnvVar.MD_REPORT_ZEROS),
+    )
 
     parser.addini(
         Ini.MD_REPORT, type="bool", default=False, help=HelpMsg.MD_REPORT,
@@ -46,6 +66,12 @@ def pytest_addoption(parser):
     parser.addini(
         Ini.MD_REPORT_COLOR, default=None, help=HelpMsg.MD_REPORT_COLOR,
     )
+    parser.addini(
+        Ini.MD_REPORT_MARGIN, default=None, help=HelpMsg.MD_REPORT_MARGIN,
+    )
+    parser.addini(
+        Ini.MD_REPORT_ZEROS, default=None, help=HelpMsg.MD_REPORT_ZEROS,
+    )
 
 
 def is_make_md_report(config: Config) -> bool:
@@ -108,6 +134,36 @@ def retrieve_report_color(config: Config) -> str:
     return report_color
 
 
+def retrieve_report_margin(config: Config) -> int:
+    margin = config.option.md_report_margin
+
+    if margin is None:
+        margin = _to_int(os.environ.get(EnvVar.MD_REPORT_MARGIN))
+
+    if margin is None:
+        margin = _to_int(config.getini(Ini.MD_REPORT_MARGIN))
+
+    if margin is None:
+        return Default.MARGIN
+
+    return margin
+
+
+def retrieve_report_zeros(config: Config) -> str:
+    report_zeros = config.option.md_report_zeros
+
+    if not report_zeros:
+        report_zeros = os.environ.get(EnvVar.MD_REPORT_ZEROS)
+
+    if not report_zeros:
+        report_zeros = config.getini(Ini.MD_REPORT_ZEROS)
+
+    if not report_zeros:
+        report_zeros = Default.ZEROS
+
+    return report_zeros
+
+
 def _normalize_stat_name(name: str) -> str:
     if name == "error":
         return "errors"
@@ -136,10 +192,10 @@ class ColorRetriever:
 
         if (self.__row % 2) == 0:
             fg_color = FGColor.GRAYOUT if self.__is_grayout else base_color
-            bg_color = BGColor.EVEN_ROW if self.__report_color == "auto" else None
+            bg_color = BGColor.EVEN_ROW if self.__report_color == ColorPoicy.AUTO else None
         else:
             fg_color = FGColor.GRAYOUT if self.__is_grayout else base_color
-            bg_color = BGColor.ODD_ROW if self.__report_color == "auto" else None
+            bg_color = BGColor.ODD_ROW if self.__report_color == ColorPoicy.AUTO else None
 
         return (fg_color, bg_color)
 
@@ -204,7 +260,6 @@ def col_separator_style_filter(
     fg_color = None
     bg_color = None
     row = left_cell.row if left_cell else cast(Cell, right_cell).row
-    col = left_cell.col if left_cell else cast(Cell, right_cell).col
 
     if row % 2 == 0:
         bg_color = BGColor.EVEN_ROW
@@ -260,14 +315,20 @@ def make_md_report(
         writer.headers = [Header.FILEPATH, Header.TESTFUNC] + outcomes
         matrix.append(["TOTAL", ""] + [total_stats.get(key, 0) for key in outcomes])  # type: ignore
 
-    writer.margin = 1
+    writer.margin = retrieve_report_margin(config)
     writer.value_matrix = matrix
 
     report_color = retrieve_report_color(config)
-    if report_color != "never":
+    if report_color != ColorPoicy.NEVER:
         writer.style_filter_kwargs = {"report_color": report_color}
         writer.add_style_filter(style_filter)
-        writer.add_col_separator_style_filter(col_separator_style_filter)
+
+        if report_color == ColorPoicy.AUTO:
+            writer.add_col_separator_style_filter(col_separator_style_filter)
+
+    report_zeros = retrieve_report_zeros(config)
+    if report_zeros == ZerosRender.EMPTY:
+        writer.register_trans_func(zero_to_nullstr)
 
     return writer.dumps()
 
